@@ -21,12 +21,24 @@ class LoadingProgressBar(QProgressBar):
     def __loading(self, v):
         self.setValue(v)
         if self.__animation.currentValue() == self.__animation.endValue():
-            self.__animation.stop()
             self.__animation.setDirection(QAbstractAnimation.Backward)
             self.setInvertedAppearance(True)
             self.__animation.start()
         elif self.__animation.currentValue() == self.__animation.startValue():
-            self.__animation.stop()
             self.__animation.setDirection(QAbstractAnimation.Forward)
             self.setInvertedAppearance(False)
-            self.__animation.start()
\ No newline at end of file
+            self.__animation.start()
+
+    def setAnimationType(self, type: str):
+        if type == 'fade':
+            self.setStyleSheet('''
+                QProgressBar::chunk {
+                    background-color: qlineargradient(x1:0, y1:0, x2:1, y2:0, stop:0 transparent, stop: 0.5 #CCCCCC, stop: 0.6 #CCCCCC, stop:1 transparent);
+                }
+            ''')
+            self.__animation.setEasingCurve(QEasingCurve.Linear)
+            self.__animation.setDuration(500)
+        elif type == 'dynamic':
+            self.setStyleSheet('')
+            self.__animation.setEasingCurve(QEasingCurve.InOutQuad)
+            self.__animation.setDuration(1000)
